# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class NftOwner(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "block_number_minted",
            "contract_type",
            "symbol",
            "owner_of",
            "token_hash",
            "token_id",
            "last_metadata_sync",
            "name",
            "block_number",
            "token_address",
            "last_token_uri_sync",
        }
        
        class properties:
            token_address = schemas.StrSchema
            token_id = schemas.StrSchema
            contract_type = schemas.StrSchema
            owner_of = schemas.StrSchema
            block_number = schemas.StrSchema
            block_number_minted = schemas.StrSchema
            name = schemas.StrSchema
            symbol = schemas.StrSchema
            token_hash = schemas.StrSchema
            last_token_uri_sync = schemas.StrSchema
            last_metadata_sync = schemas.StrSchema
            token_uri = schemas.StrSchema
            metadata = schemas.StrSchema
        
            @staticmethod
            def normalized_metadata() -> typing.Type['NormalizedMetadata']:
                return NormalizedMetadata
        
            @staticmethod
            def media_links() -> typing.Type['Media']:
                return Media
            amount = schemas.StrSchema
            __annotations__ = {
                "token_address": token_address,
                "token_id": token_id,
                "contract_type": contract_type,
                "owner_of": owner_of,
                "block_number": block_number,
                "block_number_minted": block_number_minted,
                "name": name,
                "symbol": symbol,
                "token_hash": token_hash,
                "last_token_uri_sync": last_token_uri_sync,
                "last_metadata_sync": last_metadata_sync,
                "token_uri": token_uri,
                "metadata": metadata,
                "normalized_metadata": normalized_metadata,
                "media_links": media_links,
                "amount": amount,
            }

    
    block_number_minted: MetaOapg.properties.block_number_minted
    contract_type: MetaOapg.properties.contract_type
    symbol: MetaOapg.properties.symbol
    owner_of: MetaOapg.properties.owner_of
    token_hash: MetaOapg.properties.token_hash
    token_id: MetaOapg.properties.token_id
    last_metadata_sync: MetaOapg.properties.last_metadata_sync
    name: MetaOapg.properties.name
    block_number: MetaOapg.properties.block_number
    token_address: MetaOapg.properties.token_address
    last_token_uri_sync: MetaOapg.properties.last_token_uri_sync
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_address"]) -> MetaOapg.properties.token_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_id"]) -> MetaOapg.properties.token_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["contract_type"]) -> MetaOapg.properties.contract_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["owner_of"]) -> MetaOapg.properties.owner_of: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_number_minted"]) -> MetaOapg.properties.block_number_minted: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_hash"]) -> MetaOapg.properties.token_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_token_uri_sync"]) -> MetaOapg.properties.last_token_uri_sync: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_metadata_sync"]) -> MetaOapg.properties.last_metadata_sync: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_uri"]) -> MetaOapg.properties.token_uri: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["normalized_metadata"]) -> 'NormalizedMetadata': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["media_links"]) -> 'Media': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["token_address", "token_id", "contract_type", "owner_of", "block_number", "block_number_minted", "name", "symbol", "token_hash", "last_token_uri_sync", "last_metadata_sync", "token_uri", "metadata", "normalized_metadata", "media_links", "amount", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_address"]) -> MetaOapg.properties.token_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_id"]) -> MetaOapg.properties.token_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["contract_type"]) -> MetaOapg.properties.contract_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["owner_of"]) -> MetaOapg.properties.owner_of: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_number_minted"]) -> MetaOapg.properties.block_number_minted: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_hash"]) -> MetaOapg.properties.token_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_token_uri_sync"]) -> MetaOapg.properties.last_token_uri_sync: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_metadata_sync"]) -> MetaOapg.properties.last_metadata_sync: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_uri"]) -> typing.Union[MetaOapg.properties.token_uri, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["normalized_metadata"]) -> typing.Union['NormalizedMetadata', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["media_links"]) -> typing.Union['Media', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> typing.Union[MetaOapg.properties.amount, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["token_address", "token_id", "contract_type", "owner_of", "block_number", "block_number_minted", "name", "symbol", "token_hash", "last_token_uri_sync", "last_metadata_sync", "token_uri", "metadata", "normalized_metadata", "media_links", "amount", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        block_number_minted: typing.Union[MetaOapg.properties.block_number_minted, str, ],
        contract_type: typing.Union[MetaOapg.properties.contract_type, str, ],
        symbol: typing.Union[MetaOapg.properties.symbol, str, ],
        owner_of: typing.Union[MetaOapg.properties.owner_of, str, ],
        token_hash: typing.Union[MetaOapg.properties.token_hash, str, ],
        token_id: typing.Union[MetaOapg.properties.token_id, str, ],
        last_metadata_sync: typing.Union[MetaOapg.properties.last_metadata_sync, str, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        block_number: typing.Union[MetaOapg.properties.block_number, str, ],
        token_address: typing.Union[MetaOapg.properties.token_address, str, ],
        last_token_uri_sync: typing.Union[MetaOapg.properties.last_token_uri_sync, str, ],
        token_uri: typing.Union[MetaOapg.properties.token_uri, str, schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, str, schemas.Unset] = schemas.unset,
        normalized_metadata: typing.Union['NormalizedMetadata', schemas.Unset] = schemas.unset,
        media_links: typing.Union['Media', schemas.Unset] = schemas.unset,
        amount: typing.Union[MetaOapg.properties.amount, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'NftOwner':
        return super().__new__(
            cls,
            *args,
            block_number_minted=block_number_minted,
            contract_type=contract_type,
            symbol=symbol,
            owner_of=owner_of,
            token_hash=token_hash,
            token_id=token_id,
            last_metadata_sync=last_metadata_sync,
            name=name,
            block_number=block_number,
            token_address=token_address,
            last_token_uri_sync=last_token_uri_sync,
            token_uri=token_uri,
            metadata=metadata,
            normalized_metadata=normalized_metadata,
            media_links=media_links,
            amount=amount,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_evm_api.model.media import Media
from openapi_evm_api.model.normalized_metadata import NormalizedMetadata



# coding: utf-8

"""
    Auth API

    API that provides authentication services for dapps.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

import unittest

import openapi_auth
from openapi_auth.model.aptos_complete_challenge_request_dto import AptosCompleteChallengeRequestDto
from openapi_auth import configuration


class TestAptosCompleteChallengeRequestDto(unittest.TestCase):
    """AptosCompleteChallengeRequestDto unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()



from openapi_streams.paths.streams_aptos_id.get import ApiForget
from openapi_streams.paths.streams_aptos_id.post import ApiForpost
from openapi_streams.paths.streams_aptos_id.delete import ApiFordelete


class StreamsAptosId(
    ApiForget,
    ApiForpost,
    ApiFordelete,
):
    pass



import typing_extensions

from openapi_aptos_api.paths import PathValues
from openapi_aptos_api.apis.paths.nfts import Nfts
from openapi_aptos_api.apis.paths.nfts_collections_collection_data_id_hash_tokens import NftsCollectionsCollectionDataIdHashTokens
from openapi_aptos_api.apis.paths.nfts_creators import NftsCreators
from openapi_aptos_api.apis.paths.collections import Collections
from openapi_aptos_api.apis.paths.collections_ids import CollectionsIds
from openapi_aptos_api.apis.paths.collections_creators import CollectionsCreators
from openapi_aptos_api.apis.paths.nfts_owners import NftsOwners
from openapi_aptos_api.apis.paths.nfts_collections_collection_data_id_hash_owners import NftsCollectionsCollectionDataIdHashOwners
from openapi_aptos_api.apis.paths.nfts_collections_collection_data_id_hash_owners_list import NftsCollectionsCollectionDataIdHashOwnersList
from openapi_aptos_api.apis.paths.nfts_transfers import NftsTransfers
from openapi_aptos_api.apis.paths.nfts_transfers_collections_collection_data_id_hash import NftsTransfersCollectionsCollectionDataIdHash
from openapi_aptos_api.apis.paths.nfts_transfers_creators import NftsTransfersCreators
from openapi_aptos_api.apis.paths.nfts_transfers_wallets import NftsTransfersWallets
from openapi_aptos_api.apis.paths.coins import Coins
from openapi_aptos_api.apis.paths.coins_latest import CoinsLatest
from openapi_aptos_api.apis.paths.coins_names import CoinsNames
from openapi_aptos_api.apis.paths.coins_symbols import CoinsSymbols
from openapi_aptos_api.apis.paths.coins_creators import CoinsCreators
from openapi_aptos_api.apis.paths.coins_transfers_wallets import CoinsTransfersWallets
from openapi_aptos_api.apis.paths.coins_transfers_blocks import CoinsTransfersBlocks
from openapi_aptos_api.apis.paths.coins_transfers_coin_type import CoinsTransfersCoinType
from openapi_aptos_api.apis.paths.coins_owners_coin_type_hash_top_holders import CoinsOwnersCoinTypeHashTopHolders
from openapi_aptos_api.apis.paths.wallets_coins import WalletsCoins
from openapi_aptos_api.apis.paths.wallets_coins_history import WalletsCoinsHistory
from openapi_aptos_api.apis.paths.wallets_coins_transfers import WalletsCoinsTransfers
from openapi_aptos_api.apis.paths.wallets_nfts import WalletsNfts
from openapi_aptos_api.apis.paths.wallets_nfts_transfers import WalletsNftsTransfers
from openapi_aptos_api.apis.paths.accounts_address import AccountsAddress
from openapi_aptos_api.apis.paths.accounts_address_resources import AccountsAddressResources
from openapi_aptos_api.apis.paths.accounts_address_modules import AccountsAddressModules
from openapi_aptos_api.apis.paths.accounts_address_resource_resource_type import AccountsAddressResourceResourceType
from openapi_aptos_api.apis.paths.accounts_address_resource_module_name import AccountsAddressResourceModuleName
from openapi_aptos_api.apis.paths.accounts_address_events_creation_number import AccountsAddressEventsCreationNumber
from openapi_aptos_api.apis.paths.accounts_address_events_event_handle_field_name import AccountsAddressEventsEventHandleFieldName
from openapi_aptos_api.apis.paths.transactions import Transactions
from openapi_aptos_api.apis.paths.transactions_by_hash_txn_hash import TransactionsByHashTxnHash
from openapi_aptos_api.apis.paths.transactions_by_version_txn_version import TransactionsByVersionTxnVersion
from openapi_aptos_api.apis.paths.accounts_address_transactions import AccountsAddressTransactions
from openapi_aptos_api.apis.paths.transactions_batch import TransactionsBatch
from openapi_aptos_api.apis.paths.transactions_simulate import TransactionsSimulate
from openapi_aptos_api.apis.paths.transactions_encode_submission import TransactionsEncodeSubmission
from openapi_aptos_api.apis.paths.transactions_estimate_gas_price import TransactionsEstimateGasPrice
from openapi_aptos_api.apis.paths.blocks_block_height import BlocksBlockHeight
from openapi_aptos_api.apis.paths.blocks_by_version_version import BlocksByVersionVersion

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.NFTS: Nfts,
        PathValues.NFTS_COLLECTIONS_COLLECTION_DATA_ID_HASH_TOKENS: NftsCollectionsCollectionDataIdHashTokens,
        PathValues.NFTS_CREATORS: NftsCreators,
        PathValues.COLLECTIONS: Collections,
        PathValues.COLLECTIONS_IDS: CollectionsIds,
        PathValues.COLLECTIONS_CREATORS: CollectionsCreators,
        PathValues.NFTS_OWNERS: NftsOwners,
        PathValues.NFTS_COLLECTIONS_COLLECTION_DATA_ID_HASH_OWNERS: NftsCollectionsCollectionDataIdHashOwners,
        PathValues.NFTS_COLLECTIONS_COLLECTION_DATA_ID_HASH_OWNERS_LIST: NftsCollectionsCollectionDataIdHashOwnersList,
        PathValues.NFTS_TRANSFERS: NftsTransfers,
        PathValues.NFTS_TRANSFERS_COLLECTIONS_COLLECTION_DATA_ID_HASH: NftsTransfersCollectionsCollectionDataIdHash,
        PathValues.NFTS_TRANSFERS_CREATORS: NftsTransfersCreators,
        PathValues.NFTS_TRANSFERS_WALLETS: NftsTransfersWallets,
        PathValues.COINS: Coins,
        PathValues.COINS_LATEST: CoinsLatest,
        PathValues.COINS_NAMES: CoinsNames,
        PathValues.COINS_SYMBOLS: CoinsSymbols,
        PathValues.COINS_CREATORS: CoinsCreators,
        PathValues.COINS_TRANSFERS_WALLETS: CoinsTransfersWallets,
        PathValues.COINS_TRANSFERS_BLOCKS: CoinsTransfersBlocks,
        PathValues.COINS_TRANSFERS_COIN_TYPE: CoinsTransfersCoinType,
        PathValues.COINS_OWNERS_COIN_TYPE_HASH_TOPHOLDERS: CoinsOwnersCoinTypeHashTopHolders,
        PathValues.WALLETS_COINS: WalletsCoins,
        PathValues.WALLETS_COINS_HISTORY: WalletsCoinsHistory,
        PathValues.WALLETS_COINS_TRANSFERS: WalletsCoinsTransfers,
        PathValues.WALLETS_NFTS: WalletsNfts,
        PathValues.WALLETS_NFTS_TRANSFERS: WalletsNftsTransfers,
        PathValues.ACCOUNTS_ADDRESS: AccountsAddress,
        PathValues.ACCOUNTS_ADDRESS_RESOURCES: AccountsAddressResources,
        PathValues.ACCOUNTS_ADDRESS_MODULES: AccountsAddressModules,
        PathValues.ACCOUNTS_ADDRESS_RESOURCE_RESOURCE_TYPE: AccountsAddressResourceResourceType,
        PathValues.ACCOUNTS_ADDRESS_RESOURCE_MODULE_NAME: AccountsAddressResourceModuleName,
        PathValues.ACCOUNTS_ADDRESS_EVENTS_CREATION_NUMBER: AccountsAddressEventsCreationNumber,
        PathValues.ACCOUNTS_ADDRESS_EVENTS_EVENT_HANDLE_FIELD_NAME: AccountsAddressEventsEventHandleFieldName,
        PathValues.TRANSACTIONS: Transactions,
        PathValues.TRANSACTIONS_BY_HASH_TXN_HASH: TransactionsByHashTxnHash,
        PathValues.TRANSACTIONS_BY_VERSION_TXN_VERSION: TransactionsByVersionTxnVersion,
        PathValues.ACCOUNTS_ADDRESS_TRANSACTIONS: AccountsAddressTransactions,
        PathValues.TRANSACTIONS_BATCH: TransactionsBatch,
        PathValues.TRANSACTIONS_SIMULATE: TransactionsSimulate,
        PathValues.TRANSACTIONS_ENCODE_SUBMISSION: TransactionsEncodeSubmission,
        PathValues.TRANSACTIONS_ESTIMATE_GAS_PRICE: TransactionsEstimateGasPrice,
        PathValues.BLOCKS_BLOCK_HEIGHT: BlocksBlockHeight,
        PathValues.BLOCKS_BY_VERSION_VERSION: BlocksByVersionVersion,
    }
)

path_to_api = PathToApi(
    {
        PathValues.NFTS: Nfts,
        PathValues.NFTS_COLLECTIONS_COLLECTION_DATA_ID_HASH_TOKENS: NftsCollectionsCollectionDataIdHashTokens,
        PathValues.NFTS_CREATORS: NftsCreators,
        PathValues.COLLECTIONS: Collections,
        PathValues.COLLECTIONS_IDS: CollectionsIds,
        PathValues.COLLECTIONS_CREATORS: CollectionsCreators,
        PathValues.NFTS_OWNERS: NftsOwners,
        PathValues.NFTS_COLLECTIONS_COLLECTION_DATA_ID_HASH_OWNERS: NftsCollectionsCollectionDataIdHashOwners,
        PathValues.NFTS_COLLECTIONS_COLLECTION_DATA_ID_HASH_OWNERS_LIST: NftsCollectionsCollectionDataIdHashOwnersList,
        PathValues.NFTS_TRANSFERS: NftsTransfers,
        PathValues.NFTS_TRANSFERS_COLLECTIONS_COLLECTION_DATA_ID_HASH: NftsTransfersCollectionsCollectionDataIdHash,
        PathValues.NFTS_TRANSFERS_CREATORS: NftsTransfersCreators,
        PathValues.NFTS_TRANSFERS_WALLETS: NftsTransfersWallets,
        PathValues.COINS: Coins,
        PathValues.COINS_LATEST: CoinsLatest,
        PathValues.COINS_NAMES: CoinsNames,
        PathValues.COINS_SYMBOLS: CoinsSymbols,
        PathValues.COINS_CREATORS: CoinsCreators,
        PathValues.COINS_TRANSFERS_WALLETS: CoinsTransfersWallets,
        PathValues.COINS_TRANSFERS_BLOCKS: CoinsTransfersBlocks,
        PathValues.COINS_TRANSFERS_COIN_TYPE: CoinsTransfersCoinType,
        PathValues.COINS_OWNERS_COIN_TYPE_HASH_TOPHOLDERS: CoinsOwnersCoinTypeHashTopHolders,
        PathValues.WALLETS_COINS: WalletsCoins,
        PathValues.WALLETS_COINS_HISTORY: WalletsCoinsHistory,
        PathValues.WALLETS_COINS_TRANSFERS: WalletsCoinsTransfers,
        PathValues.WALLETS_NFTS: WalletsNfts,
        PathValues.WALLETS_NFTS_TRANSFERS: WalletsNftsTransfers,
        PathValues.ACCOUNTS_ADDRESS: AccountsAddress,
        PathValues.ACCOUNTS_ADDRESS_RESOURCES: AccountsAddressResources,
        PathValues.ACCOUNTS_ADDRESS_MODULES: AccountsAddressModules,
        PathValues.ACCOUNTS_ADDRESS_RESOURCE_RESOURCE_TYPE: AccountsAddressResourceResourceType,
        PathValues.ACCOUNTS_ADDRESS_RESOURCE_MODULE_NAME: AccountsAddressResourceModuleName,
        PathValues.ACCOUNTS_ADDRESS_EVENTS_CREATION_NUMBER: AccountsAddressEventsCreationNumber,
        PathValues.ACCOUNTS_ADDRESS_EVENTS_EVENT_HANDLE_FIELD_NAME: AccountsAddressEventsEventHandleFieldName,
        PathValues.TRANSACTIONS: Transactions,
        PathValues.TRANSACTIONS_BY_HASH_TXN_HASH: TransactionsByHashTxnHash,
        PathValues.TRANSACTIONS_BY_VERSION_TXN_VERSION: TransactionsByVersionTxnVersion,
        PathValues.ACCOUNTS_ADDRESS_TRANSACTIONS: AccountsAddressTransactions,
        PathValues.TRANSACTIONS_BATCH: TransactionsBatch,
        PathValues.TRANSACTIONS_SIMULATE: TransactionsSimulate,
        PathValues.TRANSACTIONS_ENCODE_SUBMISSION: TransactionsEncodeSubmission,
        PathValues.TRANSACTIONS_ESTIMATE_GAS_PRICE: TransactionsEstimateGasPrice,
        PathValues.BLOCKS_BLOCK_HEIGHT: BlocksBlockHeight,
        PathValues.BLOCKS_BY_VERSION_VERSION: BlocksByVersionVersion,
    }
)



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class EntryFunctionPayloadRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "function",
            "arguments",
            "type",
            "type_arguments",
        }
        
        class properties:
            type = schemas.StrSchema
            function = schemas.StrSchema
            
            
            class type_arguments(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'type_arguments':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class arguments(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'arguments':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "type": type,
                "function": function,
                "type_arguments": type_arguments,
                "arguments": arguments,
            }
    
    function: MetaOapg.properties.function
    arguments: MetaOapg.properties.arguments
    type: MetaOapg.properties.type
    type_arguments: MetaOapg.properties.type_arguments
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["function"]) -> MetaOapg.properties.function: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type_arguments"]) -> MetaOapg.properties.type_arguments: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["arguments"]) -> MetaOapg.properties.arguments: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["type", "function", "type_arguments", "arguments", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["function"]) -> MetaOapg.properties.function: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type_arguments"]) -> MetaOapg.properties.type_arguments: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["arguments"]) -> MetaOapg.properties.arguments: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["type", "function", "type_arguments", "arguments", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        function: typing.Union[MetaOapg.properties.function, str, ],
        arguments: typing.Union[MetaOapg.properties.arguments, list, tuple, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        type_arguments: typing.Union[MetaOapg.properties.type_arguments, list, tuple, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'EntryFunctionPayloadRequest':
        return super().__new__(
            cls,
            *args,
            function=function,
            arguments=arguments,
            type=type,
            type_arguments=type_arguments,
            _configuration=_configuration,
            **kwargs,
        )



from .get_account import get_account
from .get_account_module import get_account_module
from .get_account_modules import get_account_modules
from .get_account_resource import get_account_resource
from .get_account_resources import get_account_resources
from .get_events_by_creation_number import get_events_by_creation_number
from .get_events_by_event_handle import get_events_by_event_handle



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_streams.paths.streams_aptos_id_address import Api

from openapi_streams.paths import PathValues

path = PathValues.STREAMS_APTOS_ID_ADDRESS


import typing_extensions

from openapi_auth.paths import PathValues
from openapi_auth.apis.paths.challenge_request_evm import ChallengeRequestEvm
from openapi_auth.apis.paths.challenge_verify_evm import ChallengeVerifyEvm
from openapi_auth.apis.paths.challenge_request_solana import ChallengeRequestSolana
from openapi_auth.apis.paths.challenge_verify_solana import ChallengeVerifySolana
from openapi_auth.apis.paths.challenge_request_aptos import ChallengeRequestAptos
from openapi_auth.apis.paths.challenge_verify_aptos import ChallengeVerifyAptos
from openapi_auth.apis.paths.profile_profile_id_addresses import ProfileProfileIdAddresses
from openapi_auth.apis.paths.bind_request import BindRequest
from openapi_auth.apis.paths.bind_request_verify import BindRequestVerify
from openapi_auth.apis.paths.bind_remove import BindRemove
from openapi_auth.apis.paths.bind_remove_verify import BindRemoveVerify

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.CHALLENGE_REQUEST_EVM: ChallengeRequestEvm,
        PathValues.CHALLENGE_VERIFY_EVM: ChallengeVerifyEvm,
        PathValues.CHALLENGE_REQUEST_SOLANA: ChallengeRequestSolana,
        PathValues.CHALLENGE_VERIFY_SOLANA: ChallengeVerifySolana,
        PathValues.CHALLENGE_REQUEST_APTOS: ChallengeRequestAptos,
        PathValues.CHALLENGE_VERIFY_APTOS: ChallengeVerifyAptos,
        PathValues.PROFILE_PROFILE_ID_ADDRESSES: ProfileProfileIdAddresses,
        PathValues.BIND_REQUEST: BindRequest,
        PathValues.BIND_REQUEST_VERIFY: BindRequestVerify,
        PathValues.BIND_REMOVE: BindRemove,
        PathValues.BIND_REMOVE_VERIFY: BindRemoveVerify,
    }
)

path_to_api = PathToApi(
    {
        PathValues.CHALLENGE_REQUEST_EVM: ChallengeRequestEvm,
        PathValues.CHALLENGE_VERIFY_EVM: ChallengeVerifyEvm,
        PathValues.CHALLENGE_REQUEST_SOLANA: ChallengeRequestSolana,
        PathValues.CHALLENGE_VERIFY_SOLANA: ChallengeVerifySolana,
        PathValues.CHALLENGE_REQUEST_APTOS: ChallengeRequestAptos,
        PathValues.CHALLENGE_VERIFY_APTOS: ChallengeVerifyAptos,
        PathValues.PROFILE_PROFILE_ID_ADDRESSES: ProfileProfileIdAddresses,
        PathValues.BIND_REQUEST: BindRequest,
        PathValues.BIND_REQUEST_VERIFY: BindRequestVerify,
        PathValues.BIND_REMOVE: BindRemove,
        PathValues.BIND_REMOVE_VERIFY: BindRemoveVerify,
    }
)



import typing_extensions

from openapi_sol_api.apis.tags import TagValues
from openapi_sol_api.apis.tags.account_api import AccountApi
from openapi_sol_api.apis.tags.nft_api import NftApi
from openapi_sol_api.apis.tags.token_api import TokenApi

TagToApi = typing_extensions.TypedDict(
    'TagToApi',
    {
        TagValues.ACCOUNT: AccountApi,
        TagValues.NFT: NftApi,
        TagValues.TOKEN: TokenApi,
    }
)

tag_to_api = TagToApi(
    {
        TagValues.ACCOUNT: AccountApi,
        TagValues.NFT: NftApi,
        TagValues.TOKEN: TokenApi,
    }
)



import typing_extensions

from openapi_streams.apis.tags import TagValues
from openapi_streams.apis.tags.aptos_streams_api import AptosStreamsApi
from openapi_streams.apis.tags.evm_streams_api import EvmStreamsApi
from openapi_streams.apis.tags.history_api import HistoryApi
from openapi_streams.apis.tags.logs_api import LogsApi
from openapi_streams.apis.tags.project_api import ProjectApi
from openapi_streams.apis.tags.stats_api import StatsApi

TagToApi = typing_extensions.TypedDict(
    'TagToApi',
    {
        TagValues.APTOS_STREAMS: AptosStreamsApi,
        TagValues.EVM_STREAMS: EvmStreamsApi,
        TagValues.HISTORY: HistoryApi,
        TagValues.LOGS: LogsApi,
        TagValues.PROJECT: ProjectApi,
        TagValues.STATS: StatsApi,
    }
)

tag_to_api = TagToApi(
    {
        TagValues.APTOS_STREAMS: AptosStreamsApi,
        TagValues.EVM_STREAMS: EvmStreamsApi,
        TagValues.HISTORY: HistoryApi,
        TagValues.LOGS: LogsApi,
        TagValues.PROJECT: ProjectApi,
        TagValues.STATS: StatsApi,
    }
)



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class HistoricalCoinBalanceDto(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "amount",
            "coin_type_hash",
            "coin_type",
            "owner_address",
            "transaction_timestamp",
            "transaction_version",
        }
        
        class properties:
            
            
            class amount(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 200
                    min_length = 1
            
            
            class coin_type(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 5000
                    min_length = 1
            
            
            class coin_type_hash(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 64
                    min_length = 64
            transaction_timestamp = schemas.StrSchema
            transaction_version = schemas.StrSchema
            
            
            class owner_address(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 66
                    min_length = 66
            __annotations__ = {
                "amount": amount,
                "coin_type": coin_type,
                "coin_type_hash": coin_type_hash,
                "transaction_timestamp": transaction_timestamp,
                "transaction_version": transaction_version,
                "owner_address": owner_address,
            }
    
    amount: MetaOapg.properties.amount
    coin_type_hash: MetaOapg.properties.coin_type_hash
    coin_type: MetaOapg.properties.coin_type
    owner_address: MetaOapg.properties.owner_address
    transaction_timestamp: MetaOapg.properties.transaction_timestamp
    transaction_version: MetaOapg.properties.transaction_version
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["coin_type"]) -> MetaOapg.properties.coin_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["coin_type_hash"]) -> MetaOapg.properties.coin_type_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_timestamp"]) -> MetaOapg.properties.transaction_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_version"]) -> MetaOapg.properties.transaction_version: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["owner_address"]) -> MetaOapg.properties.owner_address: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["amount", "coin_type", "coin_type_hash", "transaction_timestamp", "transaction_version", "owner_address", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["coin_type"]) -> MetaOapg.properties.coin_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["coin_type_hash"]) -> MetaOapg.properties.coin_type_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_timestamp"]) -> MetaOapg.properties.transaction_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_version"]) -> MetaOapg.properties.transaction_version: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["owner_address"]) -> MetaOapg.properties.owner_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["amount", "coin_type", "coin_type_hash", "transaction_timestamp", "transaction_version", "owner_address", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        amount: typing.Union[MetaOapg.properties.amount, str, ],
        coin_type_hash: typing.Union[MetaOapg.properties.coin_type_hash, str, ],
        coin_type: typing.Union[MetaOapg.properties.coin_type, str, ],
        owner_address: typing.Union[MetaOapg.properties.owner_address, str, ],
        transaction_timestamp: typing.Union[MetaOapg.properties.transaction_timestamp, str, ],
        transaction_version: typing.Union[MetaOapg.properties.transaction_version, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'HistoricalCoinBalanceDto':
        return super().__new__(
            cls,
            *args,
            amount=amount,
            coin_type_hash=coin_type_hash,
            coin_type=coin_type,
            owner_address=owner_address,
            transaction_timestamp=transaction_timestamp,
            transaction_version=transaction_version,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

import unittest

import openapi_aptos_api
from openapi_aptos_api.model.coin_transfer_dto import CoinTransferDto
from openapi_aptos_api import configuration


class TestCoinTransferDto(unittest.TestCase):
    """CoinTransferDto unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Auth API

    API that provides authentication services for dapps.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from openapi_auth.paths.bind_remove.post import RemoveBind
from openapi_auth.paths.bind_request.post import RequestBind
from openapi_auth.paths.bind_remove_verify.post import VerifyRemoveBind
from openapi_auth.paths.bind_request_verify.post import VerifyRequestBind


class BindApi(
    RemoveBind,
    RequestBind,
    VerifyRemoveBind,
    VerifyRequestBind,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_aptos_api.paths.wallets_coins.get import GetCoinBalancesByWallets
from openapi_aptos_api.paths.wallets_coins_transfers.get import GetCoinTransfersByWalletAddresses
from openapi_aptos_api.paths.wallets_coins_history.get import GetHistoricalCoinBalancesByWallets
from openapi_aptos_api.paths.wallets_nfts.get import GetNftByOwners
from openapi_aptos_api.paths.wallets_nfts_transfers.get import GetWalletsNftTransfers


class WalletsApi(
    GetCoinBalancesByWallets,
    GetCoinTransfersByWalletAddresses,
    GetHistoricalCoinBalancesByWallets,
    GetNftByOwners,
    GetWalletsNftTransfers,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class Media(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "media_collection",
            "mimetype",
            "original_media_url",
            "category",
            "parent_hash",
        }
        
        class properties:
            mimetype = schemas.StrSchema
            
            
            class category(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "image": "IMAGE",
                        "audio": "AUDIO",
                        "video": "VIDEO",
                    }
                
                @schemas.classproperty
                def IMAGE(cls):
                    return cls("image")
                
                @schemas.classproperty
                def AUDIO(cls):
                    return cls("audio")
                
                @schemas.classproperty
                def VIDEO(cls):
                    return cls("video")
            original_media_url = schemas.StrSchema
            parent_hash = schemas.StrSchema
        
            @staticmethod
            def media_collection() -> typing.Type['MediaCollection']:
                return MediaCollection
            __annotations__ = {
                "mimetype": mimetype,
                "category": category,
                "original_media_url": original_media_url,
                "parent_hash": parent_hash,
                "media_collection": media_collection,
            }

    
    media_collection: 'MediaCollection'
    mimetype: MetaOapg.properties.mimetype
    original_media_url: MetaOapg.properties.original_media_url
    category: MetaOapg.properties.category
    parent_hash: MetaOapg.properties.parent_hash
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["mimetype"]) -> MetaOapg.properties.mimetype: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["category"]) -> MetaOapg.properties.category: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["original_media_url"]) -> MetaOapg.properties.original_media_url: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["parent_hash"]) -> MetaOapg.properties.parent_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["media_collection"]) -> 'MediaCollection': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["mimetype", "category", "original_media_url", "parent_hash", "media_collection", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["mimetype"]) -> MetaOapg.properties.mimetype: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["category"]) -> MetaOapg.properties.category: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["original_media_url"]) -> MetaOapg.properties.original_media_url: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["parent_hash"]) -> MetaOapg.properties.parent_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["media_collection"]) -> 'MediaCollection': ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["mimetype", "category", "original_media_url", "parent_hash", "media_collection", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        media_collection: 'MediaCollection',
        mimetype: typing.Union[MetaOapg.properties.mimetype, str, ],
        original_media_url: typing.Union[MetaOapg.properties.original_media_url, str, ],
        category: typing.Union[MetaOapg.properties.category, str, ],
        parent_hash: typing.Union[MetaOapg.properties.parent_hash, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Media':
        return super().__new__(
            cls,
            *args,
            media_collection=media_collection,
            mimetype=mimetype,
            original_media_url=original_media_url,
            category=category,
            parent_hash=parent_hash,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_evm_api.model.media_collection import MediaCollection



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_aptos_api.apis.path_to_api import path_to_api



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

import logging
import ssl
from urllib.parse import urlencode
import typing

import certifi
import urllib3
from urllib3._collections import HTTPHeaderDict

from openapi_aptos_api.exceptions import ApiException, ApiValueError


logger = logging.getLogger(__name__)


class RESTClientObject(object):

    def __init__(self, configuration, pools_size=4, maxsize=None):
        # urllib3.PoolManager will pass all kw parameters to connectionpool
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/poolmanager.py#L75  # noqa: E501
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/connectionpool.py#L680  # noqa: E501
        # maxsize is the number of requests to host that are allowed in parallel  # noqa: E501
        # Custom SSL certificates and client certificates: http://urllib3.readthedocs.io/en/latest/advanced-usage.html  # noqa: E501

        # cert_reqs
        if configuration.verify_ssl:
            cert_reqs = ssl.CERT_REQUIRED
        else:
            cert_reqs = ssl.CERT_NONE

        # ca_certs
        if configuration.ssl_ca_cert:
            ca_certs = configuration.ssl_ca_cert
        else:
            # if not set certificate file, use Mozilla's root certificates.
            ca_certs = certifi.where()

        addition_pool_args = {}
        if configuration.assert_hostname is not None:
            addition_pool_args['assert_hostname'] = configuration.assert_hostname  # noqa: E501

        if configuration.retries is not None:
            addition_pool_args['retries'] = configuration.retries

        if configuration.socket_options is not None:
            addition_pool_args['socket_options'] = configuration.socket_options

        if maxsize is None:
            if configuration.connection_pool_maxsize is not None:
                maxsize = configuration.connection_pool_maxsize
            else:
                maxsize = 4

        # https pool manager
        if configuration.proxy:
            self.pool_manager = urllib3.ProxyManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                proxy_url=configuration.proxy,
                proxy_headers=configuration.proxy_headers,
                **addition_pool_args
            )
        else:
            self.pool_manager = urllib3.PoolManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                **addition_pool_args
            )

    def request(
        self,
        method: str,
        url: str,
        headers: typing.Optional[HTTPHeaderDict] = None,
        fields: typing.Optional[typing.Tuple[typing.Tuple[str, typing.Any], ...]] = None,
        body: typing.Optional[typing.Union[str, bytes]] = None,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> urllib3.HTTPResponse:
        """Perform requests.

        :param method: http request method
        :param url: http request url
        :param headers: http request headers
        :param body: request body, for other types
        :param fields: request parameters for
                                `application/x-www-form-urlencoded`
                                or `multipart/form-data`
        :param stream: if True, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is False.
        :param timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
        """
        method = method.upper()
        assert method in ['GET', 'HEAD', 'DELETE', 'POST', 'PUT',
                          'PATCH', 'OPTIONS']

        if fields and body:
            raise ApiValueError(
                "body parameter cannot be used with fields parameter."
            )

        fields = fields or {}
        headers = headers or {}

        if timeout:
            if isinstance(timeout, (int, float)):  # noqa: E501,F821
                timeout = urllib3.Timeout(total=timeout)
            elif (isinstance(timeout, tuple) and
                  len(timeout) == 2):
                timeout = urllib3.Timeout(connect=timeout[0], read=timeout[1])

        try:
            # For `POST`, `PUT`, `PATCH`, `OPTIONS`, `DELETE`
            if method in ['POST', 'PUT', 'PATCH', 'OPTIONS', 'DELETE']:
                if 'Content-Type' not in headers and body is None:
                    r = self.pool_manager.request(
                        method,
                        url,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers
                    )
                elif headers['Content-Type'] == 'application/x-www-form-urlencoded':  # noqa: E501
                    r = self.pool_manager.request(
                        method, url,
                        body=body,
                        fields=fields,
                        encode_multipart=False,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers)
                elif headers['Content-Type'] == 'multipart/form-data':
                    # must del headers['Content-Type'], or the correct
                    # Content-Type which generated by urllib3 will be
                    # overwritten.
                    del headers['Content-Type']
                    r = self.pool_manager.request(
                        method, url,
                        fields=fields,
                        encode_multipart=True,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers)
                # Pass a `string` parameter directly in the body to support
                # other content types than Json when `body` argument is
                # provided in serialized form
                elif isinstance(body, str) or isinstance(body, bytes):
                    request_body = body
                    r = self.pool_manager.request(
                        method, url,
                        body=request_body,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers)
                else:
                    # Cannot generate the request from given parameters
                    msg = """Cannot prepare a request message for provided
                             arguments. Please check that your arguments match
                             declared content type."""
                    raise ApiException(status=0, reason=msg)
            # For `GET`, `HEAD`
            else:
                r = self.pool_manager.request(method, url,
                                              preload_content=not stream,
                                              timeout=timeout,
                                              headers=headers)
        except urllib3.exceptions.SSLError as e:
            msg = "{0}\n{1}".format(type(e).__name__, str(e))
            raise ApiException(status=0, reason=msg)

        if not stream:
            # log response body
            logger.debug("response body: %s", r.data)

        return r

    def GET(self, url, headers=None, stream=False,
            timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("GET", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            fields=fields)

    def HEAD(self, url, headers=None, stream=False,
             timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("HEAD", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            fields=fields)

    def OPTIONS(self, url, headers=None,
                body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("OPTIONS", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def DELETE(self, url, headers=None, body=None,
               stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("DELETE", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def POST(self, url, headers=None,
             body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("POST", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def PUT(self, url, headers=None,
            body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("PUT", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def PATCH(self, url, headers=None,
              body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("PATCH", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_evm_api.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    BALANCE = "balance"
    BLOCK = "block"
    DEFAULT = "default"
    DEFI = "defi"
    EVENTS = "events"
    IPFS = "ipfs"
    NFT = "nft"
    RESOLVE = "resolve"
    TOKEN = "token"
    TRANSACTION = "transaction"
    UTILS = "utils"



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_sol_api.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    ACCOUNT_NETWORK_ADDRESS_BALANCE = "/account/{network}/{address}/balance"
    ACCOUNT_NETWORK_ADDRESS_TOKENS = "/account/{network}/{address}/tokens"
    ACCOUNT_NETWORK_ADDRESS_NFT = "/account/{network}/{address}/nft"
    ACCOUNT_NETWORK_ADDRESS_PORTFOLIO = "/account/{network}/{address}/portfolio"
    NFT_NETWORK_ADDRESS_METADATA = "/nft/{network}/{address}/metadata"
    TOKEN_NETWORK_ADDRESS_PRICE = "/token/{network}/{address}/price"



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_evm_api.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    ADDRESS_NFT = "/{address}/nft"
    NFT_GET_MULTIPLE_NFTS = "/nft/getMultipleNFTs"
    ADDRESS_NFT_TRANSFERS = "/{address}/nft/transfers"
    ADDRESS_NFT_COLLECTIONS = "/{address}/nft/collections"
    NFT_ADDRESS = "/nft/{address}"
    NFT_ADDRESS_OWNERS = "/nft/{address}/owners"
    NFT_ADDRESS_TRANSFERS = "/nft/{address}/transfers"
    NFT_TRANSFERS = "/nft/transfers"
    BLOCK_BLOCK_NUMBER_OR_HASH_NFT_TRANSFERS = "/block/{block_number_or_hash}/nft/transfers"
    NFT_ADDRESS_TRADES = "/nft/{address}/trades"
    NFT_ADDRESS_METADATA = "/nft/{address}/metadata"
    NFT_ADDRESS_TOKEN_ID = "/nft/{address}/{token_id}"
    NFT_ADDRESS_TOKEN_ID_TRANSFERS = "/nft/{address}/{token_id}/transfers"
    NFT_ADDRESS_TOKEN_ID_OWNERS = "/nft/{address}/{token_id}/owners"
    NFT_ADDRESS_SYNC = "/nft/{address}/sync"
    NFT_ADDRESS_TOKEN_ID_METADATA_RESYNC = "/nft/{address}/{token_id}/metadata/resync"
    NFT_ADDRESS_LOWESTPRICE = "/nft/{address}/lowestprice"
    NFT_SEARCH = "/nft/search"
    ERC20_ADDRESS_PRICE = "/erc20/{address}/price"
    ADDRESS_ERC20 = "/{address}/erc20"
    ADDRESS_ERC20_TRANSFERS = "/{address}/erc20/transfers"
    ERC20_METADATA = "/erc20/metadata"
    ERC20_METADATA_SYMBOLS = "/erc20/metadata/symbols"
    ERC20_ADDRESS_ALLOWANCE = "/erc20/{address}/allowance"
    ERC20_ADDRESS_TRANSFERS = "/erc20/{address}/transfers"
    ERC20_TRANSFERS = "/erc20/transfers"
    ERC20_MINTS = "/erc20/mints"
    ERC20_BURNS = "/erc20/burns"
    ERC20_APPROVALS = "/erc20/approvals"
    ADDRESS_BALANCE = "/{address}/balance"
    WALLETS_BALANCES = "/wallets/balances"
    ADDRESS = "/{address}"
    ADDRESS_VERBOSE = "/{address}/verbose"
    TRANSACTION_TRANSACTION_HASH_INTERNALTRANSACTIONS = "/transaction/{transaction_hash}/internal-transactions"
    TRANSACTION_TRANSACTION_HASH = "/transaction/{transaction_hash}"
    TRANSACTION_TRANSACTION_HASH_VERBOSE = "/transaction/{transaction_hash}/verbose"
    BLOCK_BLOCK_NUMBER_OR_HASH = "/block/{block_number_or_hash}"
    DATETO_BLOCK = "/dateto_block"
    ADDRESS_LOGS = "/{address}/logs"
    ADDRESS_EVENTS = "/{address}/events"
    ADDRESS_FUNCTION = "/{address}/function"
    WEB3_VERSION = "/web3/version"
    INFO_ENDPOINT_WEIGHTS = "/info/endpointWeights"
    RESOLVE_ADDRESS_REVERSE = "/resolve/{address}/reverse"
    RESOLVE_DOMAIN = "/resolve/{domain}"
    PAIR_ADDRESS_RESERVES = "/{pair_address}/reserves"
    TOKEN0_ADDRESS_TOKEN1_ADDRESS_PAIR_ADDRESS = "/{token0_address}/{token1_address}/pairAddress"
    IPFS_UPLOAD_FOLDER = "/ipfs/uploadFolder"



# coding: utf-8

"""
    Solana API

    Moralis Solana API  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from openapi_sol_api.paths.account_network_address_balance.get import Balance
from openapi_sol_api.paths.account_network_address_nft.get import GetNfts
from openapi_sol_api.paths.account_network_address_portfolio.get import GetPortfolio
from openapi_sol_api.paths.account_network_address_tokens.get import GetSpl


class AccountApi(
    Balance,
    GetNfts,
    GetPortfolio,
    GetSpl,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Auth API

    API that provides authentication services for dapps.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from openapi_auth.paths.profile_profile_id_addresses.get import GetAddresses


class ProfileApi(
    GetAddresses,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class ModuleExposedFunction(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "visibility",
            "generic_type_params",
            "name",
            "is_entry",
            "params",
            "return",
        }
        
        class properties:
            name = schemas.StrSchema
            visibility = schemas.StrSchema
            is_entry = schemas.BoolSchema
            
            
            class generic_type_params(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['GenericTypeParam']:
                        return GenericTypeParam
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['GenericTypeParam'], typing.List['GenericTypeParam']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'generic_type_params':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'GenericTypeParam':
                    return super().__getitem__(i)
            
            
            class params(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'params':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class _return(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> '_return':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "name": name,
                "visibility": visibility,
                "is_entry": is_entry,
                "generic_type_params": generic_type_params,
                "params": params,
                "return": _return,
            }
    
    visibility: MetaOapg.properties.visibility
    generic_type_params: MetaOapg.properties.generic_type_params
    name: MetaOapg.properties.name
    is_entry: MetaOapg.properties.is_entry
    params: MetaOapg.properties.params
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["visibility"]) -> MetaOapg.properties.visibility: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_entry"]) -> MetaOapg.properties.is_entry: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["generic_type_params"]) -> MetaOapg.properties.generic_type_params: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["params"]) -> MetaOapg.properties.params: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["return"]) -> MetaOapg.properties._return: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "visibility", "is_entry", "generic_type_params", "params", "return", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["visibility"]) -> MetaOapg.properties.visibility: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_entry"]) -> MetaOapg.properties.is_entry: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["generic_type_params"]) -> MetaOapg.properties.generic_type_params: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["params"]) -> MetaOapg.properties.params: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["return"]) -> MetaOapg.properties._return: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "visibility", "is_entry", "generic_type_params", "params", "return", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        visibility: typing.Union[MetaOapg.properties.visibility, str, ],
        generic_type_params: typing.Union[MetaOapg.properties.generic_type_params, list, tuple, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        is_entry: typing.Union[MetaOapg.properties.is_entry, bool, ],
        params: typing.Union[MetaOapg.properties.params, list, tuple, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ModuleExposedFunction':
        return super().__new__(
            cls,
            *args,
            visibility=visibility,
            generic_type_params=generic_type_params,
            name=name,
            is_entry=is_entry,
            params=params,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_aptos_api.model.generic_type_param import GenericTypeParam



import typing_extensions

from openapi_aptos_api.apis.tags import TagValues
from openapi_aptos_api.apis.tags.accounts_api import AccountsApi
from openapi_aptos_api.apis.tags.coins_api import CoinsApi
from openapi_aptos_api.apis.tags.collections_api import CollectionsApi
from openapi_aptos_api.apis.tags.default_api import DefaultApi
from openapi_aptos_api.apis.tags.nfts_api import NftsApi
from openapi_aptos_api.apis.tags.transactions_api import TransactionsApi
from openapi_aptos_api.apis.tags.wallets_api import WalletsApi

TagToApi = typing_extensions.TypedDict(
    'TagToApi',
    {
        TagValues.ACCOUNTS: AccountsApi,
        TagValues.COINS: CoinsApi,
        TagValues.COLLECTIONS: CollectionsApi,
        TagValues.DEFAULT: DefaultApi,
        TagValues.NFTS: NftsApi,
        TagValues.TRANSACTIONS: TransactionsApi,
        TagValues.WALLETS: WalletsApi,
    }
)

tag_to_api = TagToApi(
    {
        TagValues.ACCOUNTS: AccountsApi,
        TagValues.COINS: CoinsApi,
        TagValues.COLLECTIONS: CollectionsApi,
        TagValues.DEFAULT: DefaultApi,
        TagValues.NFTS: NftsApi,
        TagValues.TRANSACTIONS: TransactionsApi,
        TagValues.WALLETS: WalletsApi,
    }
)



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class BadRequestResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            
            
            class statusCode(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 3
                    min_length = 3
            
            
            class message(
                schemas.ListBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneTupleMixin
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
                    max_items = 1000
                    min_items = 0
            
            
                def __new__(
                    cls,
                    *args: typing.Union[list, tuple, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'message':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class error(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'error':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            __annotations__ = {
                "statusCode": statusCode,
                "message": message,
                "error": error,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["statusCode"]) -> MetaOapg.properties.statusCode: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["message"]) -> MetaOapg.properties.message: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error"]) -> MetaOapg.properties.error: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["statusCode", "message", "error", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["statusCode"]) -> typing.Union[MetaOapg.properties.statusCode, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["message"]) -> typing.Union[MetaOapg.properties.message, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error"]) -> typing.Union[MetaOapg.properties.error, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["statusCode", "message", "error", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        statusCode: typing.Union[MetaOapg.properties.statusCode, str, schemas.Unset] = schemas.unset,
        message: typing.Union[MetaOapg.properties.message, list, tuple, None, schemas.Unset] = schemas.unset,
        error: typing.Union[MetaOapg.properties.error, None, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'BadRequestResponse':
        return super().__new__(
            cls,
            *args,
            statusCode=statusCode,
            message=message,
            error=error,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from openapi_auth.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from openapi_auth.model.address_info_dto import AddressInfoDto
from openapi_auth.model.aptos_challenge_request_dto import AptosChallengeRequestDto
from openapi_auth.model.aptos_challenge_response_dto import AptosChallengeResponseDto
from openapi_auth.model.aptos_complete_challenge_request_dto import AptosCompleteChallengeRequestDto
from openapi_auth.model.aptos_complete_challenge_response_dto import AptosCompleteChallengeResponseDto
from openapi_auth.model.bind_remove_dto import BindRemoveDto
from openapi_auth.model.bind_remove_response_dto import BindRemoveResponseDto
from openapi_auth.model.bind_request_dto import BindRequestDto
from openapi_auth.model.bind_request_response_dto import BindRequestResponseDto
from openapi_auth.model.bind_verify_remove_dto import BindVerifyRemoveDto
from openapi_auth.model.bind_verify_remove_response_dto import BindVerifyRemoveResponseDto
from openapi_auth.model.bind_verify_request_dto import BindVerifyRequestDto
from openapi_auth.model.bind_verify_request_response_dto import BindVerifyRequestResponseDto
from openapi_auth.model.evm_challenge_request_dto import EvmChallengeRequestDto
from openapi_auth.model.evm_challenge_response_dto import EvmChallengeResponseDto
from openapi_auth.model.evm_complete_challenge_request_dto import EvmCompleteChallengeRequestDto
from openapi_auth.model.evm_complete_challenge_response_dto import EvmCompleteChallengeResponseDto
from openapi_auth.model.solana_challenge_request_dto import SolanaChallengeRequestDto
from openapi_auth.model.solana_challenge_response_dto import SolanaChallengeResponseDto
from openapi_auth.model.solana_complete_challenge_request_dto import SolanaCompleteChallengeRequestDto
from openapi_auth.model.solana_complete_challenge_response_dto import SolanaCompleteChallengeResponseDto
from openapi_auth.model.verification_dto import VerificationDto



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class PickAptosStreamTypeStatusOrStatusMessage(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    From T, pick a set of properties whose keys are in the union K
    """


    class MetaOapg:
        required = {
            "statusMessage",
            "status",
        }
        
        class properties:
        
            @staticmethod
            def status() -> typing.Type['StreamsStatus']:
                return StreamsStatus
            statusMessage = schemas.StrSchema
            __annotations__ = {
                "status": status,
                "statusMessage": statusMessage,
            }
    
    statusMessage: MetaOapg.properties.statusMessage
    status: 'StreamsStatus'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'StreamsStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["statusMessage"]) -> MetaOapg.properties.statusMessage: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["status", "statusMessage", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> 'StreamsStatus': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["statusMessage"]) -> MetaOapg.properties.statusMessage: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["status", "statusMessage", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        statusMessage: typing.Union[MetaOapg.properties.statusMessage, str, ],
        status: 'StreamsStatus',
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PickAptosStreamTypeStatusOrStatusMessage':
        return super().__new__(
            cls,
            *args,
            statusMessage=statusMessage,
            status=status,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_streams.model.streams_status import StreamsStatus



# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from openapi_sol_api.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from openapi_sol_api.model.metaplex_nft import MetaplexNFT
from openapi_sol_api.model.nft_metadata import NFTMetadata
from openapi_sol_api.model.native_balance import NativeBalance
from openapi_sol_api.model.portfolio import Portfolio
from openapi_sol_api.model.splnft import SPLNFT
from openapi_sol_api.model.spl_native_price import SPLNativePrice
from openapi_sol_api.model.spl_token_balance import SPLTokenBalance
from openapi_sol_api.model.spl_token_price import SPLTokenPrice



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class NftTransferCollection(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "cursor",
            "result",
            "total",
            "page",
            "page_size",
        }
        
        class properties:
            total = schemas.IntSchema
            page = schemas.IntSchema
            page_size = schemas.IntSchema
            cursor = schemas.StrSchema
            
            
            class result(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['NftTransfer']:
                        return NftTransfer
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['NftTransfer'], typing.List['NftTransfer']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'result':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'NftTransfer':
                    return super().__getitem__(i)
            block_exists = schemas.BoolSchema
            index_complete = schemas.BoolSchema
            __annotations__ = {
                "total": total,
                "page": page,
                "page_size": page_size,
                "cursor": cursor,
                "result": result,
                "block_exists": block_exists,
                "index_complete": index_complete,
            }

    
    cursor: MetaOapg.properties.cursor
    result: MetaOapg.properties.result
    total: MetaOapg.properties.total
    page: MetaOapg.properties.page
    page_size: MetaOapg.properties.page_size
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["page"]) -> MetaOapg.properties.page: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["page_size"]) -> MetaOapg.properties.page_size: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["cursor"]) -> MetaOapg.properties.cursor: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["result"]) -> MetaOapg.properties.result: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_exists"]) -> MetaOapg.properties.block_exists: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["index_complete"]) -> MetaOapg.properties.index_complete: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["total", "page", "page_size", "cursor", "result", "block_exists", "index_complete", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["page"]) -> MetaOapg.properties.page: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["page_size"]) -> MetaOapg.properties.page_size: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["cursor"]) -> MetaOapg.properties.cursor: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["result"]) -> MetaOapg.properties.result: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_exists"]) -> typing.Union[MetaOapg.properties.block_exists, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["index_complete"]) -> typing.Union[MetaOapg.properties.index_complete, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["total", "page", "page_size", "cursor", "result", "block_exists", "index_complete", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        cursor: typing.Union[MetaOapg.properties.cursor, str, ],
        result: typing.Union[MetaOapg.properties.result, list, tuple, ],
        total: typing.Union[MetaOapg.properties.total, decimal.Decimal, int, ],
        page: typing.Union[MetaOapg.properties.page, decimal.Decimal, int, ],
        page_size: typing.Union[MetaOapg.properties.page_size, decimal.Decimal, int, ],
        block_exists: typing.Union[MetaOapg.properties.block_exists, bool, schemas.Unset] = schemas.unset,
        index_complete: typing.Union[MetaOapg.properties.index_complete, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'NftTransferCollection':
        return super().__new__(
            cls,
            *args,
            cursor=cursor,
            result=result,
            total=total,
            page=page,
            page_size=page_size,
            block_exists=block_exists,
            index_complete=index_complete,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_evm_api.model.nft_transfer import NftTransfer



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from openapi_evm_api.paths.erc20_approvals.get import GetErc20Approvals
from openapi_evm_api.paths.erc20_burns.get import GetErc20Burns
from openapi_evm_api.paths.erc20_mints.get import GetErc20Mints
from openapi_evm_api.paths.erc20_transfers.get import GetErc20Transfers
from openapi_evm_api.paths.erc20_address_allowance.get import GetTokenAllowance
from openapi_evm_api.paths.erc20_metadata.get import GetTokenMetadata
from openapi_evm_api.paths.erc20_metadata_symbols.get import GetTokenMetadataBySymbol
from openapi_evm_api.paths.erc20_address_price.get import GetTokenPrice
from openapi_evm_api.paths.erc20_address_transfers.get import GetTokenTransfers
from openapi_evm_api.paths.address_erc20.get import GetWalletTokenBalances
from openapi_evm_api.paths.address_erc20_transfers.get import GetWalletTokenTransfers


class TokenApi(
    GetErc20Approvals,
    GetErc20Burns,
    GetErc20Mints,
    GetErc20Transfers,
    GetTokenAllowance,
    GetTokenMetadata,
    GetTokenMetadataBySymbol,
    GetTokenPrice,
    GetTokenTransfers,
    GetWalletTokenBalances,
    GetWalletTokenTransfers,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Solana API

    Moralis Solana API  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from openapi_sol_api.paths.nft_network_address_metadata.get import GetNftMetadata


class NftApi(
    GetNftMetadata,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from .get_coin_info_by_coin_type_hashes import get_coin_info_by_coin_type_hashes
from .get_coin_transfers_by_block_heights import get_coin_transfers_by_block_heights
from .get_coin_transfers_by_coin_type import get_coin_transfers_by_coin_type
from .get_coin_transfers_by_owner_addresses import get_coin_transfers_by_owner_addresses
from .get_coins_by_creators import get_coins_by_creators
from .get_coins_by_name_range import get_coins_by_name_range
from .get_coins_by_symbol_range import get_coins_by_symbol_range
from .get_latest_coins import get_latest_coins
from .get_top_holders_by_coin import get_top_holders_by_coin



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

import unittest

import openapi_evm_api
from openapi_evm_api.model.erc20_burn_response import Erc20BurnResponse
from openapi_evm_api import configuration


class TestErc20BurnResponse(unittest.TestCase):
    """Erc20BurnResponse unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class EncodeSubmissionRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "sequence_number",
            "secondary_signers",
            "payload",
            "sender",
            "gas_unit_price",
            "max_gas_amount",
            "expiration_timestamp_secs",
        }
        
        class properties:
            sender = schemas.StrSchema
            sequence_number = schemas.StrSchema
            max_gas_amount = schemas.StrSchema
            gas_unit_price = schemas.StrSchema
            expiration_timestamp_secs = schemas.StrSchema
            
            
            class payload(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def one_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            EntryFunctionPayloadRequest,
                            ScriptPayloadRequest,
                            ModuleBundlePayloadRequest,
                        ]
            
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'payload':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class secondary_signers(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'secondary_signers':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "sender": sender,
                "sequence_number": sequence_number,
                "max_gas_amount": max_gas_amount,
                "gas_unit_price": gas_unit_price,
                "expiration_timestamp_secs": expiration_timestamp_secs,
                "payload": payload,
                "secondary_signers": secondary_signers,
            }
    
    sequence_number: MetaOapg.properties.sequence_number
    secondary_signers: MetaOapg.properties.secondary_signers
    payload: MetaOapg.properties.payload
    sender: MetaOapg.properties.sender
    gas_unit_price: MetaOapg.properties.gas_unit_price
    max_gas_amount: MetaOapg.properties.max_gas_amount
    expiration_timestamp_secs: MetaOapg.properties.expiration_timestamp_secs
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sender"]) -> MetaOapg.properties.sender: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sequence_number"]) -> MetaOapg.properties.sequence_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["max_gas_amount"]) -> MetaOapg.properties.max_gas_amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gas_unit_price"]) -> MetaOapg.properties.gas_unit_price: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expiration_timestamp_secs"]) -> MetaOapg.properties.expiration_timestamp_secs: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["payload"]) -> MetaOapg.properties.payload: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["secondary_signers"]) -> MetaOapg.properties.secondary_signers: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["sender", "sequence_number", "max_gas_amount", "gas_unit_price", "expiration_timestamp_secs", "payload", "secondary_signers", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sender"]) -> MetaOapg.properties.sender: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sequence_number"]) -> MetaOapg.properties.sequence_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["max_gas_amount"]) -> MetaOapg.properties.max_gas_amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gas_unit_price"]) -> MetaOapg.properties.gas_unit_price: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expiration_timestamp_secs"]) -> MetaOapg.properties.expiration_timestamp_secs: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["payload"]) -> MetaOapg.properties.payload: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["secondary_signers"]) -> MetaOapg.properties.secondary_signers: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["sender", "sequence_number", "max_gas_amount", "gas_unit_price", "expiration_timestamp_secs", "payload", "secondary_signers", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        sequence_number: typing.Union[MetaOapg.properties.sequence_number, str, ],
        secondary_signers: typing.Union[MetaOapg.properties.secondary_signers, list, tuple, ],
        payload: typing.Union[MetaOapg.properties.payload, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        sender: typing.Union[MetaOapg.properties.sender, str, ],
        gas_unit_price: typing.Union[MetaOapg.properties.gas_unit_price, str, ],
        max_gas_amount: typing.Union[MetaOapg.properties.max_gas_amount, str, ],
        expiration_timestamp_secs: typing.Union[MetaOapg.properties.expiration_timestamp_secs, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'EncodeSubmissionRequest':
        return super().__new__(
            cls,
            *args,
            sequence_number=sequence_number,
            secondary_signers=secondary_signers,
            payload=payload,
            sender=sender,
            gas_unit_price=gas_unit_price,
            max_gas_amount=max_gas_amount,
            expiration_timestamp_secs=expiration_timestamp_secs,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_aptos_api.model.entry_function_payload_request import EntryFunctionPayloadRequest
from openapi_aptos_api.model.module_bundle_payload_request import ModuleBundlePayloadRequest
from openapi_aptos_api.model.script_payload_request import ScriptPayloadRequest



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class MoveModuleAbi(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "address",
            "structs",
            "name",
            "exposed_functions",
            "friends",
        }
        
        class properties:
            address = schemas.StrSchema
            name = schemas.StrSchema
            
            
            class friends(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'friends':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class exposed_functions(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['ModuleExposedFunction']:
                        return ModuleExposedFunction
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['ModuleExposedFunction'], typing.List['ModuleExposedFunction']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'exposed_functions':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'ModuleExposedFunction':
                    return super().__getitem__(i)
            
            
            class structs(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['ModuleStruct']:
                        return ModuleStruct
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['ModuleStruct'], typing.List['ModuleStruct']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'structs':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'ModuleStruct':
                    return super().__getitem__(i)
            __annotations__ = {
                "address": address,
                "name": name,
                "friends": friends,
                "exposed_functions": exposed_functions,
                "structs": structs,
            }
    
    address: MetaOapg.properties.address
    structs: MetaOapg.properties.structs
    name: MetaOapg.properties.name
    exposed_functions: MetaOapg.properties.exposed_functions
    friends: MetaOapg.properties.friends
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["friends"]) -> MetaOapg.properties.friends: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["exposed_functions"]) -> MetaOapg.properties.exposed_functions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["structs"]) -> MetaOapg.properties.structs: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["address", "name", "friends", "exposed_functions", "structs", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["friends"]) -> MetaOapg.properties.friends: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["exposed_functions"]) -> MetaOapg.properties.exposed_functions: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["structs"]) -> MetaOapg.properties.structs: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["address", "name", "friends", "exposed_functions", "structs", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        address: typing.Union[MetaOapg.properties.address, str, ],
        structs: typing.Union[MetaOapg.properties.structs, list, tuple, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        exposed_functions: typing.Union[MetaOapg.properties.exposed_functions, list, tuple, ],
        friends: typing.Union[MetaOapg.properties.friends, list, tuple, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'MoveModuleAbi':
        return super().__new__(
            cls,
            *args,
            address=address,
            structs=structs,
            name=name,
            exposed_functions=exposed_functions,
            friends=friends,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_aptos_api.model.module_exposed_function import ModuleExposedFunction
from openapi_aptos_api.model.module_struct import ModuleStruct



from .get_nft_owners_by_collection import get_nft_owners_by_collection
from .get_nft_owners_by_tokens import get_nft_owners_by_tokens
from .get_nft_owners_of_collection import get_nft_owners_of_collection
from .get_nft_transfers_by_collection import get_nft_transfers_by_collection
from .get_nft_transfers_by_creators import get_nft_transfers_by_creators
from .get_nft_transfers_by_ids import get_nft_transfers_by_ids
from .get_nft_transfers_by_wallets import get_nft_transfers_by_wallets
from .get_nfts_by_collection import get_nfts_by_collection
from .get_nfts_by_creators import get_nfts_by_creators
from .get_nfts_by_ids import get_nfts_by_ids



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class Transaction(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "gas_price",
            "receipt_status",
            "receipt_contract_address",
            "receipt_cumulative_gas_used",
            "block_hash",
            "block_number",
            "to_address",
            "transaction_index",
            "nonce",
            "input",
            "receipt_gas_used",
            "block_timestamp",
            "gas",
            "from_address",
            "receipt_root",
            "value",
            "hash",
        }
        
        class properties:
            hash = schemas.StrSchema
            nonce = schemas.StrSchema
            transaction_index = schemas.StrSchema
            from_address = schemas.StrSchema
            to_address = schemas.StrSchema
            value = schemas.StrSchema
            gas = schemas.StrSchema
            gas_price = schemas.StrSchema
            input = schemas.StrSchema
            receipt_cumulative_gas_used = schemas.StrSchema
            receipt_gas_used = schemas.StrSchema
            receipt_contract_address = schemas.StrSchema
            receipt_root = schemas.StrSchema
            receipt_status = schemas.StrSchema
            block_timestamp = schemas.StrSchema
            block_number = schemas.StrSchema
            block_hash = schemas.StrSchema
            
            
            class internal_transactions(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['InternalTransaction']:
                        return InternalTransaction
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['InternalTransaction'], typing.List['InternalTransaction']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'internal_transactions':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'InternalTransaction':
                    return super().__getitem__(i)
            __annotations__ = {
                "hash": hash,
                "nonce": nonce,
                "transaction_index": transaction_index,
                "from_address": from_address,
                "to_address": to_address,
                "value": value,
                "gas": gas,
                "gas_price": gas_price,
                "input": input,
                "receipt_cumulative_gas_used": receipt_cumulative_gas_used,
                "receipt_gas_used": receipt_gas_used,
                "receipt_contract_address": receipt_contract_address,
                "receipt_root": receipt_root,
                "receipt_status": receipt_status,
                "block_timestamp": block_timestamp,
                "block_number": block_number,
                "block_hash": block_hash,
                "internal_transactions": internal_transactions,
            }

    
    gas_price: MetaOapg.properties.gas_price
    receipt_status: MetaOapg.properties.receipt_status
    receipt_contract_address: MetaOapg.properties.receipt_contract_address
    receipt_cumulative_gas_used: MetaOapg.properties.receipt_cumulative_gas_used
    block_hash: MetaOapg.properties.block_hash
    block_number: MetaOapg.properties.block_number
    to_address: MetaOapg.properties.to_address
    transaction_index: MetaOapg.properties.transaction_index
    nonce: MetaOapg.properties.nonce
    input: MetaOapg.properties.input
    receipt_gas_used: MetaOapg.properties.receipt_gas_used
    block_timestamp: MetaOapg.properties.block_timestamp
    gas: MetaOapg.properties.gas
    from_address: MetaOapg.properties.from_address
    receipt_root: MetaOapg.properties.receipt_root
    value: MetaOapg.properties.value
    hash: MetaOapg.properties.hash
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hash"]) -> MetaOapg.properties.hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["nonce"]) -> MetaOapg.properties.nonce: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_index"]) -> MetaOapg.properties.transaction_index: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["from_address"]) -> MetaOapg.properties.from_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["to_address"]) -> MetaOapg.properties.to_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gas"]) -> MetaOapg.properties.gas: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gas_price"]) -> MetaOapg.properties.gas_price: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["input"]) -> MetaOapg.properties.input: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["receipt_cumulative_gas_used"]) -> MetaOapg.properties.receipt_cumulative_gas_used: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["receipt_gas_used"]) -> MetaOapg.properties.receipt_gas_used: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["receipt_contract_address"]) -> MetaOapg.properties.receipt_contract_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["receipt_root"]) -> MetaOapg.properties.receipt_root: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["receipt_status"]) -> MetaOapg.properties.receipt_status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["internal_transactions"]) -> MetaOapg.properties.internal_transactions: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["hash", "nonce", "transaction_index", "from_address", "to_address", "value", "gas", "gas_price", "input", "receipt_cumulative_gas_used", "receipt_gas_used", "receipt_contract_address", "receipt_root", "receipt_status", "block_timestamp", "block_number", "block_hash", "internal_transactions", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hash"]) -> MetaOapg.properties.hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["nonce"]) -> MetaOapg.properties.nonce: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_index"]) -> MetaOapg.properties.transaction_index: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["from_address"]) -> MetaOapg.properties.from_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["to_address"]) -> MetaOapg.properties.to_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gas"]) -> MetaOapg.properties.gas: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gas_price"]) -> MetaOapg.properties.gas_price: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["input"]) -> MetaOapg.properties.input: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["receipt_cumulative_gas_used"]) -> MetaOapg.properties.receipt_cumulative_gas_used: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["receipt_gas_used"]) -> MetaOapg.properties.receipt_gas_used: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["receipt_contract_address"]) -> MetaOapg.properties.receipt_contract_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["receipt_root"]) -> MetaOapg.properties.receipt_root: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["receipt_status"]) -> MetaOapg.properties.receipt_status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["internal_transactions"]) -> typing.Union[MetaOapg.properties.internal_transactions, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["hash", "nonce", "transaction_index", "from_address", "to_address", "value", "gas", "gas_price", "input", "receipt_cumulative_gas_used", "receipt_gas_used", "receipt_contract_address", "receipt_root", "receipt_status", "block_timestamp", "block_number", "block_hash", "internal_transactions", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        gas_price: typing.Union[MetaOapg.properties.gas_price, str, ],
        receipt_status: typing.Union[MetaOapg.properties.receipt_status, str, ],
        receipt_contract_address: typing.Union[MetaOapg.properties.receipt_contract_address, str, ],
        receipt_cumulative_gas_used: typing.Union[MetaOapg.properties.receipt_cumulative_gas_used, str, ],
        block_hash: typing.Union[MetaOapg.properties.block_hash, str, ],
        block_number: typing.Union[MetaOapg.properties.block_number, str, ],
        to_address: typing.Union[MetaOapg.properties.to_address, str, ],
        transaction_index: typing.Union[MetaOapg.properties.transaction_index, str, ],
        nonce: typing.Union[MetaOapg.properties.nonce, str, ],
        input: typing.Union[MetaOapg.properties.input, str, ],
        receipt_gas_used: typing.Union[MetaOapg.properties.receipt_gas_used, str, ],
        block_timestamp: typing.Union[MetaOapg.properties.block_timestamp, str, ],
        gas: typing.Union[MetaOapg.properties.gas, str, ],
        from_address: typing.Union[MetaOapg.properties.from_address, str, ],
        receipt_root: typing.Union[MetaOapg.properties.receipt_root, str, ],
        value: typing.Union[MetaOapg.properties.value, str, ],
        hash: typing.Union[MetaOapg.properties.hash, str, ],
        internal_transactions: typing.Union[MetaOapg.properties.internal_transactions, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Transaction':
        return super().__new__(
            cls,
            *args,
            gas_price=gas_price,
            receipt_status=receipt_status,
            receipt_contract_address=receipt_contract_address,
            receipt_cumulative_gas_used=receipt_cumulative_gas_used,
            block_hash=block_hash,
            block_number=block_number,
            to_address=to_address,
            transaction_index=transaction_index,
            nonce=nonce,
            input=input,
            receipt_gas_used=receipt_gas_used,
            block_timestamp=block_timestamp,
            gas=gas,
            from_address=from_address,
            receipt_root=receipt_root,
            value=value,
            hash=hash,
            internal_transactions=internal_transactions,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_evm_api.model.internal_transaction import InternalTransaction



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from openapi_aptos_api import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401

from openapi_aptos_api.model.bad_request_response import BadRequestResponse
from openapi_aptos_api.model.nft_transfers_by_wallets_response import NFTTransfersByWalletsResponse

from . import path

# Query params


class LimitSchema(
    schemas.NumberSchema
):


    class MetaOapg:
        inclusive_maximum = 100
        inclusive_minimum = 1


class OffsetSchema(
    schemas.NumberSchema
):


    class MetaOapg:
        inclusive_maximum = 100
        inclusive_minimum = 0


class CursorSchema(
    schemas.StrBase,
    schemas.NoneBase,
    schemas.Schema,
    schemas.NoneStrMixin
):


    def __new__(
        cls,
        *args: typing.Union[None, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'CursorSchema':
        return super().__new__(
            cls,
            *args,
            _configuration=_configuration,
        )


class WalletAddressesSchema(
    schemas.ListSchema
):


    class MetaOapg:
        max_items = 25
        min_items = 1
        items = schemas.StrSchema

    def __new__(
        cls,
        arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'WalletAddressesSchema':
        return super().__new__(
            cls,
            arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)


class CollectionBlacklistSchema(
    schemas.ListBase,
    schemas.NoneBase,
    schemas.Schema,
    schemas.NoneTupleMixin
):


    class MetaOapg:
        items = schemas.StrSchema
        max_items = 25
        min_items = 1


    def __new__(
        cls,
        *args: typing.Union[list, tuple, None, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'CollectionBlacklistSchema':
        return super().__new__(
            cls,
            *args,
            _configuration=_configuration,
        )


class CollectionWhitelistSchema(
    schemas.ListBase,
    schemas.NoneBase,
    schemas.Schema,
    schemas.NoneTupleMixin
):


    class MetaOapg:
        items = schemas.StrSchema
        max_items = 25
        min_items = 1


    def __new__(
        cls,
        *args: typing.Union[list, tuple, None, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'CollectionWhitelistSchema':
        return super().__new__(
            cls,
            *args,
            _configuration=_configuration,
        )
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
        'limit': typing.Union[LimitSchema, decimal.Decimal, int, float, ],
        'wallet_addresses': typing.Union[WalletAddressesSchema, list, tuple, ],
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'offset': typing.Union[OffsetSchema, decimal.Decimal, int, float, ],
        'cursor': typing.Union[CursorSchema, None, str, ],
        'collection_blacklist': typing.Union[CollectionBlacklistSchema, list, tuple, None, ],
        'collection_whitelist': typing.Union[CollectionWhitelistSchema, list, tuple, None, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_limit = api_client.QueryParameter(
    name="limit",
    style=api_client.ParameterStyle.FORM,
    schema=LimitSchema,
    required=True,
    explode=True,
)
request_query_offset = api_client.QueryParameter(
    name="offset",
    style=api_client.ParameterStyle.FORM,
    schema=OffsetSchema,
    explode=True,
)
request_query_cursor = api_client.QueryParameter(
    name="cursor",
    style=api_client.ParameterStyle.FORM,
    schema=CursorSchema,
    explode=True,
)
request_query_wallet_addresses = api_client.QueryParameter(
    name="wallet_addresses",
    style=api_client.ParameterStyle.FORM,
    schema=WalletAddressesSchema,
    required=True,
    explode=True,
)
request_query_collection_blacklist = api_client.QueryParameter(
    name="collection_blacklist",
    style=api_client.ParameterStyle.FORM,
    schema=CollectionBlacklistSchema,
    explode=True,
)
request_query_collection_whitelist = api_client.QueryParameter(
    name="collection_whitelist",
    style=api_client.ParameterStyle.FORM,
    schema=CollectionWhitelistSchema,
    explode=True,
)
_auth = [
    'bearer',
]
SchemaFor200ResponseBodyApplicationJson = NFTTransfersByWalletsResponse


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)
SchemaFor400ResponseBodyApplicationJson = BadRequestResponse


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor400ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor400ResponseBodyApplicationJson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
    '400': _response_for_400,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _get_nft_transfers_by_wallets_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def _get_nft_transfers_by_wallets_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _get_nft_transfers_by_wallets_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _get_nft_transfers_by_wallets_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        Get NFT Transfers by wallets
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_limit,
            request_query_offset,
            request_query_cursor,
            request_query_wallet_addresses,
            request_query_collection_blacklist,
            request_query_collection_whitelist,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class GetNftTransfersByWallets(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def get_nft_transfers_by_wallets(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get_nft_transfers_by_wallets(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get_nft_transfers_by_wallets(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get_nft_transfers_by_wallets(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._get_nft_transfers_by_wallets_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._get_nft_transfers_by_wallets_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


